package visual.dynamic.described;

import java.util.*;

import visual.statik.TransformableContent;

/**
 * An abstract rule-based Sprite.
 *
 * @author  Prof. David Bernstein, James Madison University
 * @see     "The Design and Implementation of Multimedia Software  2011"
 * @version 1.0
 *
 */
public abstract class RuleBasedSprite extends AbstractSprite
{
  protected ArrayList<Sprite>         antagonists;    
  protected TransformableContent      content;

  /**
   * Explicit Value Constructor.
   *
   * @param content   The static visual content
   */
  public RuleBasedSprite(TransformableContent content)
  {
    super();

    antagonists = new ArrayList<Sprite>();       
    this.content = content;
    setVisible(true);
  }

  /**
   * Add a "antagonist" Sprite to this Sprite.
   *
   * @param antagonist   The "antagonist" Sprite to add
   */
  public void addAntagonist(Sprite antagonist)
  {
    antagonists.add(antagonist);       
  }

  /**
   * Get the visual content associated with this Sprite
   * (required by Sprite).
   */
  public TransformableContent getContent()
  {
    return content;
  }

  /**
   * Handle a tick event (required by MetronomeListener).
   *
   * @param time  The current time (in milliseconds)
   */
  public abstract void handleTick(int time);


  /**
   * Remove a "antagonist" Sprite from the collection of
   * "antagonists" this Sprite is concerned with.
   *
   * @param antagonist   The "antagonist" Sprite to remove
   */
  public void removeAntagonist(Sprite antagonist)
  {
    antagonists.remove(antagonist);       
  }
}
